@@ -275,7 +275,7 @@ static DWORD start_time=0;
 
 static DWORD get_timestamp(void)
 {
-#if USE_HW_TIMER
+#ifdef USE_HW_TIMER
 	return timer_int_counter<<1;
 #else
 	return xtm_elapse(start_time);
