@@ -197,7 +197,7 @@ static void unicorn_atm_stopdevice(struct unicorn_atmdrv *drv)
 
 	atm_dev->link_rate = 0;	
 	atm_dev->signal = ATM_PHY_SIG_LOST;
-	shutdown_atm_dev(atm_dev);
+	atm_dev_deregister(atm_dev);
 	drv->atm_dev = NULL;
 }
 
@@ -337,6 +337,27 @@ static void tx_free_skb(struct sk_buff *skb)
 	}
 }
 
+static void tx_unlink_skb(struct unicorn_atmdrv *drv,struct sk_buff *skb)
+{
+	if (skb) {
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,14))
+		struct atm_vcc *vcc = ATM_EXT_SKB(skb)->atm_skb_data.vcc;
+		if (vcc) {
+			if ((vcc->qos.txtp.traffic_class == ATM_CBR) || 
+			    (vcc->qos.txtp.traffic_class ==  ATM_VBR)) {
+				skb_unlink(skb, &drv->rt_tx_q);
+			} else {
+				skb_unlink(skb, &drv->tx_q);
+			}
+		} else {
+			WARN("cannot unlink skb, no vcc in skb\n");
+		}
+#else
+		skb_unlink(skb);
+#endif
+	}
+}
+
 static inline struct sk_buff *peek_tx_skb(struct unicorn_atmdrv *drv)
 {
 	struct sk_buff *skb;
@@ -504,7 +525,7 @@ static void snd_poll(struct unicorn_atmdrv *drv)
 
 		if (finished) {
 			// Finished with this buffer
-			skb_unlink(skb);
+			tx_unlink_skb(drv,skb);
 			tx_free_skb(skb); 	
 			// Get next buffer
 			skb = peek_tx_skb(drv);
@@ -1223,13 +1244,13 @@ static int unicorn_atm_ioctl(struct atm_dev *atm_dev, unsigned int cmd, void *ar
 		err = put_user(ATM_LM_NONE, (int *) arg) ? -EFAULT : 0;
 		break;
 	case ATM_MSW_CTL:
-		copy_from_user(&ctrl,arg,sizeof(T_MswCtrl));
+		err = copy_from_user(&ctrl,arg,sizeof(T_MswCtrl));
 		// if a buffer is provided, copy it to kernel space
 		if ((ctrl.length) && (ctrl.buffer)) {
 			user_buffer = ctrl.buffer;
 			ctrl.buffer = kmalloc(ctrl.length,GFP_KERNEL);
 			if (!ctrl.buffer) return -ENOMEM;
-			copy_from_user(ctrl.buffer,user_buffer,ctrl.length);
+			err = copy_from_user(ctrl.buffer,user_buffer,ctrl.length);
 		} else {
 			user_buffer = NULL;
 		}
@@ -1244,7 +1265,7 @@ static int unicorn_atm_ioctl(struct atm_dev *atm_dev, unsigned int cmd, void *ar
 		}
 
 		if ((ctrl.length) && (ctrl.buffer)) { 
-			copy_to_user(user_buffer,ctrl.buffer,ctrl.length);
+			err = copy_to_user(user_buffer,ctrl.buffer,ctrl.length);
 			kfree(ctrl.buffer);
 			ctrl.buffer = user_buffer;
 		}
