@@ -486,7 +486,11 @@ static void snd_poll(struct unicorn_ethdrv *drv)
 
 		if (finished) {
 			// Finished with this buffer
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,14))
+			skb_unlink(skb,&drv->tx_q);
+#else
 			skb_unlink(skb);
+#endif
 			dev_kfree_skb_any(skb);
 			// Get next buffer
 			skb = peek_tx_skb(drv);
@@ -1303,13 +1307,13 @@ static int unicorn_eth_ioctl(struct net_device *eth_dev, struct ifreq *rq, int c
 
 	switch (cmd) {
 	case ETH_MSW_CTL:
-		copy_from_user(&ctrl,rq->ifr_data,sizeof(T_MswCtrl));
+		err = copy_from_user(&ctrl,rq->ifr_data,sizeof(T_MswCtrl));
 		// if a buffer is provided, copy it to kernel space
 		if ((ctrl.length) && (ctrl.buffer)) {
 			user_buffer = ctrl.buffer;
 			ctrl.buffer = kmalloc(ctrl.length,GFP_KERNEL);
 			if (!ctrl.buffer) return -ENOMEM;
-			copy_from_user(ctrl.buffer,user_buffer,ctrl.length);
+			err = copy_from_user(ctrl.buffer,user_buffer,ctrl.length);
 		} else {
 			user_buffer = NULL;
 		}
@@ -1323,7 +1327,7 @@ static int unicorn_eth_ioctl(struct net_device *eth_dev, struct ifreq *rq, int c
 		} else {
 		}
 		if ((ctrl.length) && (ctrl.buffer)) { 
-			copy_to_user(user_buffer,ctrl.buffer,ctrl.length);
+			err = copy_to_user(user_buffer,ctrl.buffer,ctrl.length);
 			kfree(ctrl.buffer);
 			ctrl.buffer = user_buffer;
 		}
