@@ -1,7 +1,7 @@
 /*
   This driver supports the Unicorn ADSL chipset from STMicroelectronics.
   The chipset consists of the ADSL DMT transceiver ST70137 and either the
-  ST70134A or ST70136 Analog Front End (AFE).
+  ST70134A, ST70136 or ST20174 Analog Front End (AFE).
   This file contains the PCI specific routines.
 */
 #include <linux/config.h>
@@ -54,7 +54,7 @@ static inline DWORD PCI_GET_DWORD(volatile void *base,int reg)
 	return readl((PBYTE)base + reg);
 }
 
-#if BIG_ENDIAN
+#ifdef BIG_ENDIAN
 static inline void PCI_SWAP_BUF(DWORD *buf,DWORD size)
 {
 	int i;
@@ -123,6 +123,7 @@ extern unsigned long decreaseHighCarrier;
 extern unsigned long _boostPowerGdmt_;
 extern unsigned long g_ModemState;
 extern unsigned long _trellisact_;
+extern unsigned long pvo_pembdpllpolarity;
 
 unsigned long AutoActivation=1;
 unsigned long LoopbackMode=0;
@@ -1778,7 +1779,7 @@ ST_STATUS PCI_MessageWrite (T_Msg *p)
 	return status;
 }
 
-#if NOT_USED
+#ifdef NOT_USED
 //----------------------------------------------------------------------
 //	PCI_ReadConfigHeader
 //----------------------------------------------------------------------
@@ -2209,8 +2210,7 @@ unicorn_pci_init(void)
 		} else if (pci_dev->subsystem_device == 0xA889) {
 			useAFE = 20174;
 		} else {
-			// default 70134 until 20174 supported
-			useAFE = 70134;
+			useAFE = 20174;
 		}
 		
 	}
@@ -2245,14 +2245,15 @@ unicorn_pci_init(void)
 	decreaseHighCarrier = 12;
 	_boostPowerGdmt_ = 1;
 	useRFC019v = 0;
-	useRFC029v = 7000;
+	useRFC029v = 8000;
 	useRFC040v = 0;
 	useRFCFixedRate = 1;
 	TrainingDelay = 120;
 	ExchangeDelay = 20;
 	_trellisact_ = 1;
+	pvo_pembdpllpolarity=1;
 
-	Interoperability=1;
+	Interoperability=0;
 
 	INFO("v %d.%d.%d, " __TIME__ " " __DATE__"\n",
 	     (VERS>>8)&0xf,(VERS>>4)&0xf,VERS&0xf);
